@@ -1,5 +1,7 @@
 use super::*;
-use std::fmt::Display;
+
+/// A parser which can parse text into ast, and report errors at the same time
+pub type Parser = fn(&str, &mut Vec<NoteError>) -> Result<ASTNode>;
 
 pub struct PluginParser {
     pub name: String,
@@ -30,7 +32,7 @@ impl Default for PluginParser {
     }
 }
 
-pub fn text_view_parser(_: &str, _: &mut FileMeta) -> Result<ASTNode> {
+pub fn text_view_parser(_: &str, _: &mut Vec<NoteError>) -> Result<ASTNode> {
     Ok(ASTNode::default())
 }
 
